"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DkgRound1Command = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const core_1 = require("@oclif/core");
const command_1 = require("../../../../command");
const flags_1 = require("../../../../flags");
const longPrompt_1 = require("../../../../utils/longPrompt");
const multisig_1 = require("../../../../utils/multisig");
class DkgRound1Command extends command_1.IronfishCommand {
    async start() {
        const { flags } = await this.parse(DkgRound1Command);
        const client = await this.sdk.connectRpc();
        let participantName = flags.participantName;
        if (!participantName) {
            participantName = await (0, multisig_1.selectSecret)(client);
        }
        let identities = flags.identity;
        if (!identities || identities.length < 2) {
            const input = await (0, longPrompt_1.longPrompt)('Enter the identities of all participants, separated by commas', {
                required: true,
            });
            identities = input.split(',');
            if (identities.length < 2) {
                this.error('Minimum number of identities must be at least 2');
            }
        }
        identities = identities.map((i) => i.trim());
        let minSigners = flags.minSigners;
        if (!minSigners) {
            const input = await core_1.CliUx.ux.prompt('Enter the number of minimum signers', {
                required: true,
            });
            minSigners = parseInt(input);
            if (isNaN(minSigners) || minSigners < 2) {
                this.error('Minimum number of signers must be at least 2');
            }
        }
        const response = await client.wallet.multisig.dkg.round1({
            participantName,
            participants: identities.map((identity) => ({ identity })),
            minSigners: minSigners,
        });
        this.log('\nRound 1 Encrypted Secret Package:\n');
        this.log(response.content.round1SecretPackage);
        this.log();
        this.log('\nRound 1 Public Package:\n');
        this.log(response.content.round1PublicPackage);
        this.log();
        this.log('Next step:');
        this.log('Send the round 1 public package to each participant');
    }
}
DkgRound1Command.description = 'Perform round1 of the DKG protocol for multisig account creation';
DkgRound1Command.flags = {
    ...flags_1.RemoteFlags,
    participantName: core_1.Flags.string({
        char: 'n',
        description: 'The name of the secret to use for encryption during DKG',
        aliases: ['name'],
    }),
    identity: core_1.Flags.string({
        char: 'i',
        description: 'The identity of the participants will generate the group keys (may be specified multiple times to add multiple participants)',
        multiple: true,
    }),
    minSigners: core_1.Flags.integer({
        char: 'm',
        description: 'Minimum number of signers to meet signing threshold',
    }),
};
exports.DkgRound1Command = DkgRound1Command;
//# sourceMappingURL=round1.js.map