"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MultisigIdentityCreate = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const sdk_1 = require("@ironfish/sdk");
const core_1 = require("@oclif/core");
const command_1 = require("../../../../command");
const flags_1 = require("../../../../flags");
class MultisigIdentityCreate extends command_1.IronfishCommand {
    async start() {
        const { flags } = await this.parse(MultisigIdentityCreate);
        let name = flags.name;
        if (!name) {
            name = await core_1.CliUx.ux.prompt('Enter a name for the identity', {
                required: true,
            });
        }
        const client = await this.sdk.connectRpc();
        let response;
        while (!response) {
            try {
                response = await client.wallet.multisig.createParticipant({ name });
            }
            catch (e) {
                if (e instanceof sdk_1.RpcRequestError &&
                    e.code === sdk_1.RPC_ERROR_CODES.DUPLICATE_ACCOUNT_NAME.toString()) {
                    this.log();
                    this.log(e.codeMessage);
                    name = await core_1.CliUx.ux.prompt('Enter a new name for the identity', {
                        required: true,
                    });
                }
                else {
                    throw e;
                }
            }
        }
        this.log('Identity:');
        this.log(response.content.identity);
    }
}
MultisigIdentityCreate.description = `Create a multisig participant identity`;
MultisigIdentityCreate.flags = {
    ...flags_1.RemoteFlags,
    name: core_1.Flags.string({
        char: 'n',
        description: 'Name to associate with the identity',
    }),
};
exports.MultisigIdentityCreate = MultisigIdentityCreate;
//# sourceMappingURL=create.js.map