"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MultisigIdentity = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const core_1 = require("@oclif/core");
const inquirer_1 = __importDefault(require("inquirer"));
const command_1 = require("../../../../command");
const flags_1 = require("../../../../flags");
class MultisigIdentity extends command_1.IronfishCommand {
    async start() {
        const { flags } = await this.parse(MultisigIdentity);
        const client = await this.sdk.connectRpc();
        if (flags.name) {
            const response = await client.wallet.multisig.getIdentity({ name: flags.name });
            this.log('Identity:');
            this.log(response.content.identity);
        }
        else {
            const response = await client.wallet.multisig.getIdentities();
            const choices = [];
            for (const { name, identity } of response.content.identities) {
                choices.push({
                    name,
                    value: identity,
                });
            }
            // sort identities by name
            choices.sort((a, b) => a.name.localeCompare(b.name));
            const selection = await inquirer_1.default.prompt([
                {
                    name: 'identity',
                    message: 'Select participant name to view identity',
                    type: 'list',
                    choices,
                },
            ]);
            this.log('Identity:');
            this.log(selection.identity);
        }
    }
}
MultisigIdentity.description = `Retrieve a multisig participant identity from a name`;
MultisigIdentity.flags = {
    ...flags_1.RemoteFlags,
    name: core_1.Flags.string({
        char: 'n',
        description: 'Name of the participant identity',
    }),
};
exports.MultisigIdentity = MultisigIdentity;
//# sourceMappingURL=index.js.map