"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MultisigParticipants = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const core_1 = require("@oclif/core");
const command_1 = require("../../../../command");
const flags_1 = require("../../../../flags");
class MultisigParticipants extends command_1.IronfishCommand {
    async start() {
        const client = await this.sdk.connectRpc();
        const response = await client.wallet.multisig.getIdentities();
        const participants = [];
        for (const { name, identity } of response.content.identities) {
            participants.push({
                name,
                value: identity,
            });
        }
        // sort identities by name
        participants.sort((a, b) => a.name.localeCompare(b.name));
        core_1.CliUx.ux.table(participants, {
            name: {
                header: 'Participant Name',
                get: (p) => p.name,
            },
            identity: {
                header: 'Identity',
                get: (p) => p.value,
            },
        }, {
            'no-truncate': true,
        });
    }
}
MultisigParticipants.description = 'List out all the participant names and identities';
MultisigParticipants.flags = {
    ...flags_1.RemoteFlags,
};
exports.MultisigParticipants = MultisigParticipants;
//# sourceMappingURL=index.js.map