"use strict";
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
Object.defineProperty(exports, "__esModule", { value: true });
exports.promptCurrency = void 0;
const rust_nodejs_1 = require("@ironfish/rust-nodejs");
const sdk_1 = require("@ironfish/sdk");
const core_1 = require("@oclif/core");
async function promptCurrency(options) {
    let text = options.text;
    if (options.balance) {
        const balance = await options.client.wallet.getAccountBalance({
            account: options.balance.account,
            assetId: options.assetId ?? rust_nodejs_1.Asset.nativeId().toString('hex'),
            confirmations: options.balance.confirmations,
        });
        const renderedAvailable = sdk_1.CurrencyUtils.render(balance.content.available, false, options.assetId, options.assetVerification);
        text += ` (balance ${renderedAvailable})`;
    }
    // eslint-disable-next-line no-constant-condition
    while (true) {
        const input = await core_1.CliUx.ux.prompt(text, {
            required: options.required,
        });
        if (!input) {
            return null;
        }
        const [amount, error] = sdk_1.CurrencyUtils.tryMajorToMinor(input, options.assetId, options.assetVerification);
        if (error) {
            options.logger.error(`Error: ${error.message}`);
            continue;
        }
        sdk_1.Assert.isNotNull(amount);
        if (options.minimum != null && amount < options.minimum) {
            const renderedMinimum = sdk_1.CurrencyUtils.render(options.minimum, false, options.assetId, options.assetVerification);
            options.logger.error(`Error: Minimum is ${renderedMinimum}`);
            continue;
        }
        return amount;
    }
}
exports.promptCurrency = promptCurrency;
//# sourceMappingURL=currency.js.map