"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.selectSecret = exports.MultisigTransactionJson = exports.MultisigTransactionOptionsSchema = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const sdk_1 = require("@ironfish/sdk");
const inquirer_1 = __importDefault(require("inquirer"));
const yup = __importStar(require("yup"));
exports.MultisigTransactionOptionsSchema = yup
    .object({
    identity: yup.array().of(yup.string().defined()),
    unsignedTransaction: yup.string(),
    commitment: yup.array().of(yup.string().defined()),
    signingPackage: yup.string(),
    signatureShare: yup.array().of(yup.string().defined()),
})
    .defined();
async function load(files, path) {
    if (path === undefined) {
        return {};
    }
    const data = (await files.readFile(files.resolve(path))).trim();
    const { error, result } = await sdk_1.YupUtils.tryValidate(exports.MultisigTransactionOptionsSchema, data);
    if (error) {
        throw error;
    }
    return result;
}
function resolveFlags(flags, json) {
    return {
        identity: flags.identity ?? json.identity,
        unsignedTransaction: flags.unsignedTransaction?.trim() ?? json.unsignedTransaction,
        commitment: flags.commitment ?? json.commitment,
        signingPackage: flags.signingPackage?.trim() ?? json.signingPackage,
        signatureShare: flags.signatureShare ?? json.signatureShare,
    };
}
exports.MultisigTransactionJson = {
    load,
    resolveFlags,
};
async function selectSecret(client) {
    const identitiesResponse = await client.wallet.multisig.getIdentities();
    const choices = [];
    for (const { name } of identitiesResponse.content.identities) {
        choices.push({
            name,
            value: name,
        });
    }
    choices.sort((a, b) => a.name.localeCompare(b.name));
    const selection = await inquirer_1.default.prompt([
        {
            name: 'name',
            message: 'Select participant secret name',
            type: 'list',
            choices,
        },
    ]);
    return selection.name;
}
exports.selectSecret = selectSecret;
//# sourceMappingURL=multisig.js.map