"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchNotes = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const rust_nodejs_1 = require("@ironfish/rust-nodejs");
const sdk_1 = require("@ironfish/sdk");
async function fetchNotes(client, account, notesToCombine) {
    const noteSize = await getNoteTreeSize(client);
    // TODO(mat): We need to add asset support here for bridges, etc.
    const getNotesResponse = await client.wallet.getNotes({
        account,
        pageSize: notesToCombine,
        filter: {
            assetId: rust_nodejs_1.Asset.nativeId().toString('hex'),
            spent: false,
        },
    });
    // filtering notes by noteSize and sorting them by value in ascending order
    const notes = getNotesResponse.content.notes
        .filter((note) => {
        if (!note.index) {
            return false;
        }
        return note.index < noteSize;
    })
        .sort((a, b) => {
        if (a.value < b.value) {
            return -1;
        }
        return 1;
    });
    return notes;
}
exports.fetchNotes = fetchNotes;
async function getNoteTreeSize(client) {
    const getCurrentBlock = await client.chain.getChainInfo();
    const currentBlockSequence = parseInt(getCurrentBlock.content.currentBlockIdentifier.index);
    const getBlockResponse = await client.chain.getBlock({
        sequence: currentBlockSequence,
    });
    sdk_1.Assert.isNotNull(getBlockResponse.content.block.noteSize);
    const config = await client.config.getConfig();
    // Adding a buffer to avoid a mismatch between confirmations used to load notes and confirmations used when creating witnesses to spend them
    return getBlockResponse.content.block.noteSize - (config.content.confirmations || 2);
}
//# sourceMappingURL=note.js.map